## To Install Main Package

```
pip install censius -U

```

## To Install Dev Package
```
 pip install --trusted-host pypi-dev.eastus.azurecontainer.io:8080 \
 --index-url http://pypi-dev.eastus.azurecontainer.io:8080/simple/ censius -U
```

## API Reference to execute operation

https://documentation.censius.ai/api-reference

